@@ -1,8 +1,10 @@
+pub mod google_fit_activity;
 pub mod location_history;
 pub mod my_activity;
 pub mod saved_places;
 pub mod semantic_location_history;
 
+pub use google_fit_activity::*;
 pub use location_history::*;
 pub use my_activity::*;
 pub use saved_places::*;
